package com.ruoyi.project.patrol.dev.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.patrol.dev.mapper.TDevManholeCoverMapper;
import com.ruoyi.project.patrol.dev.domain.TDevManholeCover;
import com.ruoyi.project.patrol.dev.service.ITDevManholeCoverService;

/**
 * 地井盖Service业务层处理
 * 
 * @author admin
 * @date 2023-11-08
 */
@Service
public class TDevManholeCoverServiceImpl implements ITDevManholeCoverService 
{
    @Autowired
    private TDevManholeCoverMapper tDevManholeCoverMapper;

    /**
     * 查询地井盖
     * 
     * @param id 地井盖主键
     * @return 地井盖
     */
    @Override
    public TDevManholeCover selectTDevManholeCoverById(Long id)
    {
        return tDevManholeCoverMapper.selectTDevManholeCoverById(id);
    }

    /**
     * 查询地井盖列表
     * 
     * @param tDevManholeCover 地井盖
     * @return 地井盖
     */
    @Override
    public List<TDevManholeCover> selectTDevManholeCoverList(TDevManholeCover tDevManholeCover)
    {
        return tDevManholeCoverMapper.selectTDevManholeCoverList(tDevManholeCover);
    }

    /**
     * 新增地井盖
     * 
     * @param tDevManholeCover 地井盖
     * @return 结果
     */
    @Override
    public int insertTDevManholeCover(TDevManholeCover tDevManholeCover)
    {
        return tDevManholeCoverMapper.insertTDevManholeCover(tDevManholeCover);
    }

    /**
     * 修改地井盖
     * 
     * @param tDevManholeCover 地井盖
     * @return 结果
     */
    @Override
    public int updateTDevManholeCover(TDevManholeCover tDevManholeCover)
    {
        return tDevManholeCoverMapper.updateTDevManholeCover(tDevManholeCover);
    }

    /**
     * 批量删除地井盖
     * 
     * @param ids 需要删除的地井盖主键
     * @return 结果
     */
    @Override
    public int deleteTDevManholeCoverByIds(Long[] ids)
    {
        return tDevManholeCoverMapper.deleteTDevManholeCoverByIds(ids);
    }

    /**
     * 删除地井盖信息
     * 
     * @param id 地井盖主键
     * @return 结果
     */
    @Override
    public int deleteTDevManholeCoverById(Long id)
    {
        return tDevManholeCoverMapper.deleteTDevManholeCoverById(id);
    }
}
